Attribute VB_Name = "CMQXB"
Option Explicit
'**********************************************************************'
'*                                                                    *'
'*                  IBM MQSeries for Windows NT and Windows 2000      *'
'*                                                                    *'
'*  MODULE NAME:    CMQXB                                             *'
'*                                                                    *'
'*  DESCRIPTION:    Structure and Constants for MQCD                  *'
'*                                                                    *'
'**********************************************************************'
'*  @START_COPYRIGHT@                                                 *'
'*  Licensed Materials - Property of IBM                              *'
'*                                                                    *'
'*  0784726, 5639-B43  MQSeries for Windows NT and Windows 2000       *'
'*                                                                    *'
'*  (C) Copyright IBM Corporation 1993, 2000.                         *'
'*                                                                    *'
'*  Status: Version 5 Release 2                                       *'
'*  @END_COPYRIGHT@                                                   *'
'**********************************************************************'
'*                                                                    *'
'*  FUNCTION:       This file declares the structure and named        *'
'*                  constants for MQCD.                               *'
'*                                                                    *'
'*  PROCESSOR:      BASIC                                             *'
'*                                                                    *'
'**********************************************************************'
 
'**********************************************************************'
'*  Values Related to MQCD Structure                                  *'
'**********************************************************************'
 
'Structure Version Number'
Global Const MQCD_VERSION_1       = 1
Global Const MQCD_VERSION_2       = 2
Global Const MQCD_VERSION_3       = 3
Global Const MQCD_VERSION_4       = 4
Global Const MQCD_VERSION_5       = 5
Global Const MQCD_VERSION_6       = 6
Global Const MQCD_CURRENT_VERSION = 6
 
'Channel Type'
Global Const MQCHT_SENDER    = 1
Global Const MQCHT_SERVER    = 2
Global Const MQCHT_RECEIVER  = 3
Global Const MQCHT_REQUESTER = 4
Global Const MQCHT_ALL       = 5
Global Const MQCHT_CLNTCONN  = 6
Global Const MQCHT_SVRCONN   = 7
Global Const MQCHT_CLUSRCVR  = 8
Global Const MQCHT_CLUSSDR   = 9
 
'Transport Type'
Global Const MQXPT_LOCAL   = 0
Global Const MQXPT_LU62    = 1
Global Const MQXPT_TCP     = 2
Global Const MQXPT_NETBIOS = 3
Global Const MQXPT_SPX     = 4
Global Const MQXPT_DECNET  = 5
Global Const MQXPT_UDP     = 6
 
'Put Authority'
Global Const MQPA_DEFAULT          = 1
Global Const MQPA_CONTEXT          = 2
Global Const MQPA_ONLY_MCA         = 3
Global Const MQPA_ALTERNATE_OR_MCA = 4
 
'Channel Data Conversion'
Global Const MQCDC_SENDER_CONVERSION    = 1
Global Const MQCDC_NO_SENDER_CONVERSION = 0
 
'MCA Type'
Global Const MQMCAT_PROCESS = 1
Global Const MQMCAT_THREAD  = 2
 
'NonPersistent-Message Speed'
Global Const MQNPMS_NORMAL = 1
Global Const MQNPMS_FAST   = 2
 
'Structure Length'
Global Const MQCD_LENGTH_4       = 1540
Global Const MQCD_LENGTH_5       = 1552
Global Const MQCD_LENGTH_6       = 1648
Global Const MQCD_CURRENT_LENGTH = 1648
 
 
'**********************************************************************'
'*  MQCD Structure -- Channel Definition                              *'
'**********************************************************************'
 
Type MQCD
  ChannelName            As String*20  'Channel definition name'
  Version                As Long       'Structure version number'
  ChannelType            As Long       'Channel type'
  TransportType          As Long       'Transport type'
  Desc                   As String*64  'Channel description'
  QMgrName               As String*48  'Queue-manager name'
  XmitQName              As String*48  'Transmission queue name'
  ShortConnectionName    As String*20  'First 20 bytes of connection name'
  MCAName                As String*20  'Reserved'
  ModeName               As String*8   'LU 6.2 Mode name'
  TpName                 As String*64  'LU 6.2 transaction program name'
  BatchSize              As Long       'Batch size'
  DiscInterval           As Long       'Disconnect interval'
  ShortRetryCount        As Long       'Short retry count'
  ShortRetryInterval     As Long       'Short retry wait interval'
  LongRetryCount         As Long       'Long retry count'
  LongRetryInterval      As Long       'Long retry wait interval'
  SecurityExit           As String*128 'Channel security exit name'
  MsgExit                As String*128 'Channel message exit name'
  SendExit               As String*128 'Channel send exit name'
  ReceiveExit            As String*128 'Channel receive exit name'
  SeqNumberWrap          As Long       'Highest allowable message sequence number'
  MaxMsgLength           As Long       'Maximum message length'
  PutAuthority           As Long       'Put authority'
  DataConversion         As Long       'Data conversion'
  SecurityUserData       As String*32  'Channel security exit user data'
  MsgUserData            As String*32  'Channel message exit user data'
  SendUserData           As String*32  'Channel send exit user data'
  ReceiveUserData        As String*32  'Channel receive exit user data'
  UserIdentifier         As String*12  'User identifier'
  Password               As String*12  'Password'
  MCAUserIdentifier      As String*12  'First 12 bytes of MCA user identifier'
  MCAType                As Long       'Message channel agent type'
  ConnectionName         As String*264 'Connection name'
  RemoteUserIdentifier   As String*12  'First 12 bytes of user identifier from partner'
  RemotePassword         As String*12  'Password from partner'
  MsgRetryExit           As String*128 'Channel message retry exit name'
  MsgRetryUserData       As String*32  'Channel message retry exit user data'
  MsgRetryCount          As Long       'Number of times MCA will try to put the message, after the first attempt has failed'
  MsgRetryInterval       As Long       'Minimum interval in milliseconds after which the open or put operation will be retried'
  HeartbeatInterval      As Long       'Time in seconds between heartbeat flows'
  BatchInterval          As Long       'Batch duration'
  NonPersistentMsgSpeed  As Long       'Speed at which nonpersistent messages are sent'
  StrucLength            As Long       'Length of MQCD structure'
  ExitNameLength         As Long       'Length of exit name'
  ExitDataLength         As Long       'Length of exit user data'
  MsgExitsDefined        As Long       'Number of message exits defined'
  SendExitsDefined       As Long       'Number of send exits defined'
  ReceiveExitsDefined    As Long       'Number of receive exits defined'
  MsgExitPtr             As String*4   'Address of first MsgExit field'
  MsgUserDataPtr         As String*4   'Address of first MsgUserData field'
  SendExitPtr            As String*4   'Address of first SendExit field'
  SendUserDataPtr        As String*4   'Address of first SendUserData field'
  ReceiveExitPtr         As String*4   'Address of first ReceiveExit field'
  ReceiveUserDataPtr     As String*4   'Address of first ReceiveUserData field'
  ClusterPtr             As String*4   'Address of first cluster record'
  ClustersDefined        As Long       'Number of cluster records'
  NetworkPriority        As Long       'Network priority'
  LongMCAUserIdLength    As Long       'Length of long MCA user identifier'
  LongRemoteUserIdLength As Long       'Length of long remote user identifier'
  LongMCAUserIdPtr       As String*4   'Address of long MCA user identifier'
  LongRemoteUserIdPtr    As String*4   'Address of long remote user identifier'
  MCASecurityId          As String*40  'MCA security identifier'
  RemoteSecurityId       As String*40  'Remote security identifier'
End Type
 
'Default Instance of MQCD Structure'
Global MQCD_DEFAULT As MQCD
 
 
'**********************************************************************'
'*  MQCNOCD Structure -- Connect Options Plus Channel Definition      *'
'*                                                                    *'
'*  Use this for the "ConnectOpts" parameter of the MQCONNXAny call   *'
'*  to specify the channel parameters for an MQ client application.   *'
'**********************************************************************'
 
Type MQCNOCD
  ConnectOpts As MQCNO 'Options that control the action of MQCONNX'
  ChannelDef  As MQCD  'Channel definition for client connection'
End Type
 
'Default Instance of MQCNOCD Structure'
Global MQCNOCD_DEFAULT As MQCNOCD
 
 
'**********************************************************************'
'*  Subroutines to Set Structures to Default Values                   *'
'**********************************************************************'
 
Sub MQCD_DEFAULTS (Struc As MQCD)
  Struc.ChannelName            = ""
  Struc.Version                = MQCD_CURRENT_VERSION
  Struc.ChannelType            = MQCHT_SENDER
  Struc.TransportType          = MQXPT_LU62
  Struc.Desc                   = ""
  Struc.QMgrName               = ""
  Struc.XmitQName              = ""
  Struc.ShortConnectionName    = ""
  Struc.MCAName                = ""
  Struc.ModeName               = ""
  Struc.TpName                 = ""
  Struc.BatchSize              = 50
  Struc.DiscInterval           = 6000
  Struc.ShortRetryCount        = 10
  Struc.ShortRetryInterval     = 60
  Struc.LongRetryCount         = 999999999
  Struc.LongRetryInterval      = 1200
  Struc.SecurityExit           = ""
  Struc.MsgExit                = ""
  Struc.SendExit               = ""
  Struc.ReceiveExit            = ""
  Struc.SeqNumberWrap          = 999999999
  Struc.MaxMsgLength           = 4194304
  Struc.PutAuthority           = MQPA_DEFAULT
  Struc.DataConversion         = MQCDC_NO_SENDER_CONVERSION
  Struc.SecurityUserData       = ""
  Struc.MsgUserData            = ""
  Struc.SendUserData           = ""
  Struc.ReceiveUserData        = ""
  Struc.UserIdentifier         = ""
  Struc.Password               = ""
  Struc.MCAUserIdentifier      = ""
  Struc.MCAType                = MQMCAT_PROCESS
  Struc.ConnectionName         = ""
  Struc.RemoteUserIdentifier   = ""
  Struc.RemotePassword         = ""
  Struc.MsgRetryExit           = ""
  Struc.MsgRetryUserData       = ""
  Struc.MsgRetryCount          = 10
  Struc.MsgRetryInterval       = 1000
  Struc.HeartbeatInterval      = 300
  Struc.BatchInterval          = 0
  Struc.NonPersistentMsgSpeed  = MQNPMS_FAST
  Struc.StrucLength            = MQCD_CURRENT_LENGTH
  Struc.ExitNameLength         = MQ_EXIT_NAME_LENGTH
  Struc.ExitDataLength         = MQ_EXIT_DATA_LENGTH
  Struc.MsgExitsDefined        = 0
  Struc.SendExitsDefined       = 0
  Struc.ReceiveExitsDefined    = 0
  Struc.MsgExitPtr             = String(4,0)
  Struc.MsgUserDataPtr         = String(4,0)
  Struc.SendExitPtr            = String(4,0)
  Struc.SendUserDataPtr        = String(4,0)
  Struc.ReceiveExitPtr         = String(4,0)
  Struc.ReceiveUserDataPtr     = String(4,0)
  Struc.ClusterPtr             = String(4,0)
  Struc.ClustersDefined        = 0
  Struc.NetworkPriority        = 0
  Struc.LongMCAUserIdLength    = 0
  Struc.LongRemoteUserIdLength = 0
  Struc.LongMCAUserIdPtr       = String(4,0)
  Struc.LongRemoteUserIdPtr    = String(4,0)
  Struc.MCASecurityId          = MQSID_NONE
  Struc.RemoteSecurityId       = MQSID_NONE
End Sub
 
Sub MQCNOCD_DEFAULTS (Struc As MQCNOCD)
  Dim TempConnectOpts As MQCNO
  MQCNO_DEFAULTS TempConnectOpts
  TempConnectOpts.Version = MQCNO_VERSION_2
  TempConnectOpts.ClientConnOffset = Len(TempConnectOpts)
  Struc.ConnectOpts = TempConnectOpts
  Dim TempChannelDef As MQCD
  MQCD_DEFAULTS TempChannelDef
  TempChannelDef.ChannelType = MQCHT_CLNTCONN
  TempChannelDef.TransportType = MQXPT_TCP
  TempChannelDef.HeartbeatInterval = 1
  Struc.ChannelDef = TempChannelDef
End Sub
 
 
'**********************************************************************'
'*  MQXB_DEFAULTS Subroutine -- Set Defaults                          *'
'**********************************************************************'
 
Sub MQXB_DEFAULTS ()
  'Set default structures'
  MQCD_DEFAULTS MQCD_DEFAULT
  MQCNOCD_DEFAULTS MQCNOCD_DEFAULT
End Sub
 
 
'**********************************************************************'
'*  End of CMQB                                                       *'
'**********************************************************************'
