VERSION 5.00
Begin VB.Form MQTriv
   Appearance      =   0  'Flat
   BackColor       =   &H80000005&
   Caption         =   "MQSeries Trivial VB Example"
   ClientHeight    =   3630
   ClientLeft      =   1230
   ClientTop       =   2025
   ClientWidth     =   6390
   ForeColor       =   &H80000008&
   Icon            =   "MQTRIV.frx":0000
   LinkTopic       =   "Form1"
   PaletteMode     =   1  'UseZOrder
   ScaleHeight     =   3630
   ScaleWidth      =   6390
End
Attribute VB_Name = "MQTriv"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

Private Sub Form_Activate()
  ' Display simple usage message
  Print "1. Click on the form to execute test MQSeries code."
  Print
  Print "(The test MQSeries code puts a message to the"
  Print "SYSTEM.DEFAULT.LOCAL.QUEUE"
  Print "on the default queue manager and then retrieves it.)"
  Print
  Print "2. Double-click the form to clear it."
End Sub

Private Sub Form_Click()

' This file shows a trivial MQ example,
'   putting a message and getting it back.
'
' The Visual Basic Form handling is intentionally left oversimple
' to emphasize the just the MQ part of the code. Because of this
' the form will not repaint if other windows move over it, nor will the
' text that appears in the window scroll when it reaches the bottom.
'
' In a real application we would normally expect
'   MQCONN (and perhaps MQOPEN) to be performed on Form_Load, and
'   MQDISC (and perhaps MQCLOSE) to be performed on Form_QueryUnload.
'
' The sample is included in Visual Basic projects
'    MQtrivS.vbp to invoke MQSeries server
'    MQtrivC.vbp to invoke MQSeries client.

  Dim cc As Long              ' completion code
  Dim Reason As Long          ' reason code
  Dim Hconn As Long           ' MQ connection handle
  Dim Hobj As Long            ' MQ queue handle
  Dim ObjDesc As MQOD         ' MQ object descriptor for the queue
  Dim PutMsgOpts As MQPMO     ' MQ options for the MQPUT
  Dim GetMsgOpts As MQGMO     ' MQ options for the MQGET
  Dim MsgDesc As MQMD         ' MQ descriptor for the message for put/get
  Dim readlen As Long         ' length of message got

  Dim ps As String             ' string for put
  Dim gs As String             ' string for get

  ' connect to default queue manager
  MQCONN " ", Hconn, cc, Reason
  If cc <> MQCC_OK Then
    MsgBox "MQCONN failed with code " & Reason, vbOKOnly + vbExclamation, "Error"
  Else

    ' set up the queue name and open the queue for output
    ObjDesc = MQOD_DEFAULT
    ObjDesc.ObjectName = "SYSTEM.DEFAULT.LOCAL.QUEUE"

    MQOPEN Hconn, ObjDesc, MQOO_OUTPUT Or MQOO_INPUT_AS_Q_DEF, Hobj, cc, Reason

    If cc <> MQCC_OK Then

      'COMMON PROBLEMS:
      '================================================
      '  CompCode = 2, Reason = 2085
      '================================================
      '
      'PROBLEM:
      '  QUEUENAME not found
      '
      'SOLUTION:
      '  Check spelling and case of queuename

      If Reason = 2085 Then
        MsgBox "HINT: Check the spelling of the Queue name, which is Case-Sensitive.", vbOKOnly + vbInformation, "ReasonCode = (2085) - MQRC_UNKNOWN_OBJECT_NAME"
      End If
    Else
      ' put
      PutMsgOpts = MQPMO_DEFAULT
      MsgDesc = MQMD_DEFAULT
      ps = "12345678 " & Time
      MQPUT Hconn, Hobj, MsgDesc, PutMsgOpts, Len(ps), ps, cc, Reason
      If cc <> MQCC_OK Then MsgBox "MQPUT failed with reason " & Reason, vbOKOnly + vbExclamation, "Error"
      Print
      Print "put " & ps

      ' get
      GetMsgOpts = MQGMO_DEFAULT
      MsgDesc = MQMD_DEFAULT
      gs = String(100, " ")
      MQGET Hconn, Hobj, MsgDesc, GetMsgOpts, Len(gs), gs, readlen, cc, Reason
      If cc <> MQCC_OK Then
        MsgBox "MQGET failed with code " & Reason, vbOKOnly + vbExclamation
      Else
        gs = Left(gs, readlen)
      End If
      If gs <> ps Then MsgBox "MQPUT/MQGET mismatch: '" & ps & "' <> '" & gs & "'", vbOKOnly + vbExclamation, "Error"
      Print "read back " & readlen & " bytes, '" & gs & "'"

      ' close
      MQCLOSE Hconn, Hobj, MQCO_NONE, cc, Reason
      If cc <> MQCC_OK Then MsgBox "MQCLOSE failed with code " & Reason, vbOKOnly + vbExclamation, "Error"

    End If   'If open worked

  ' Disconnect
  MQDISC Hconn, cc, Reason
  If cc <> MQCC_OK Then MsgBox "MQDISC failed with code " & Reason, vbOKOnly + vbExclamation, "Error"

  End If  ' If connect worked

End Sub


Private Sub Form_DblClick()
  ' Clear from
  Me.Cls
  ' Display simple usage message
  Print "1. Click on the form to execute test MQSeries code."
  Print
  Print "(The test MQSeries code puts a message to the"
  Print "SYSTEM.DEFAULT.LOCAL.QUEUE"
  Print "on the default queue manager and then retrieves it.)"
  Print
  Print "2. Double-click the form to clear it."

End Sub

Private Sub Form_Load()
  ' Setup default values
  MQ_SETDEFAULTS
End Sub

